package com.ruoyi.system.service;

import com.ruoyi.system.domain.houseManage.HouseManage;

import java.util.List;


/**
 * 房屋管理Service接口
 * 
 * @author boman
 * @date 2025-02-14
 */
public interface IHouseManageService 
{
    /**
     * 查询房屋管理
     * 
     * @param portalId 房屋管理主键
     * @return 房屋管理
     */
    public HouseManage selectHouseManageByPortalId(Long portalId);

    /**
     * 查询房屋管理列表
     * 
     * @param houseManage 房屋管理
     * @return 房屋管理集合
     */
    public List<HouseManage> selectHouseManageList(HouseManage houseManage);

    /**
     * 新增房屋管理
     * 
     * @param houseManage 房屋管理
     * @return 结果
     */
    public int insertHouseManage(HouseManage houseManage);

    /**
     * 修改房屋管理
     * 
     * @param houseManage 房屋管理
     * @return 结果
     */
    public int updateHouseManage(HouseManage houseManage);

    /**
     * 批量删除房屋管理
     * 
     * @param portalIds 需要删除的房屋管理主键集合
     * @return 结果
     */
    public int deleteHouseManageByPortalIds(Long[] portalIds);

    /**
     * 删除房屋管理信息
     * 
     * @param portalId 房屋管理主键
     * @return 结果
     */
    public int deleteHouseManageByPortalId(Long portalId);
}
